@@ -4,10 +4,10 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 
-from .kylinpy import KylinCluster
+from .kylinpy import Kylin, create_kylin, KylinCluster, dsn_proxy
 
-__version__ = '2.4.1'
+__version__ = '2.7.0'
 
 __all__ = [
-    'KylinCluster',
+    'Kylin', 'create_kylin', 'KylinCluster', 'dsn_proxy',
 ]
