@@ -6,10 +6,13 @@ from __future__ import unicode_literals
 
 import base64
 import logging
+import warnings
 
 from kylinpy.client import Client as HTTPClient
+from kylinpy.exceptions import KylinCubeError
 from kylinpy.service import KylinService, KE3Service, KE4Service
-from kylinpy.datasource import TableSource, CubeSource
+from kylinpy.datasource import TableSource, CubeSource, KE4ModelSource
+from kylinpy.job import KylinJob
 from kylinpy.utils.compat import as_unicode, urlparse, parse_qsl
 
 SERVICES = {
@@ -19,7 +22,7 @@ SERVICES = {
 }
 
 
-class KylinCluster(object):
+class Kylin(object):
     def __init__(self, host, username=None, password=None, port=7070, project=None, **connect_args):
         if host.startswith(('http://', 'https://')):
             _, self.host = host.split('://')
@@ -53,7 +56,7 @@ class KylinCluster(object):
             headers.update({'Accept': 'application/vnd.apache.kylin-v2+json'})
 
         if self.version == 'v4':
-            headers.update({'Accept': 'application/vnd.apache.kylin-v4+json'})
+            headers.update({'Accept': 'application/vnd.apache.kylin-v4-public+json'})
 
         if self.username and self.password:
             headers.update(self.basic_auth_dump(self.username, self.password))
@@ -105,14 +108,42 @@ class KylinCluster(object):
             return TableSource(name, schema, self.service.tables_and_columns().get(fullname))
 
     def get_cube_source(self, name):
+        warnings.warn('This method is deprecated. Please use `get_datsource()`.')
+        return self.get_datasource(name)
+
+    def get_datasource(self, name):
+        if self.version == 'v4':
+            _params = {
+                'project': self.project,
+                'page_offset': 0,
+                'page_size': 1000,
+                'model_name': name,
+                'exact': True,
+            }
+            model_desc = self.service.models(params=_params)[0]
+            return KE4ModelSource(
+                model_desc=model_desc,
+                tables_and_columns=self.service.tables_and_columns(),
+            )
+
         cube_desc = self.service.cube_desc(name)
+        if cube_desc is None:
+            raise KylinCubeError('No Cube found: {}'.format(name))
         model_name = cube_desc.get('model_name')
         return CubeSource(
             cube_desc=cube_desc,
             model_desc=self.service.model_desc(model_name),
             tables_and_columns=self.service.tables_and_columns(),
+            service=self.service,
         )
 
+    def get_job(self, job_id):
+        return KylinJob(job_id=job_id, service=self.service)
+
+    def list_job(self, **query_params):
+        jobs = self.service.jobs(params=query_params)
+        return [self.get_job(job_id=job['uuid']) for job in jobs]
+
     def __str__(self):
         if self.project:
             dsn = ('{self.scheme}://'
@@ -129,9 +160,14 @@ class KylinCluster(object):
         return '<Kylinpy instance: {}>'.format(str(self))
 
 
-def dsn_proxy(dsn):
+def create_kylin(dsn):
     url = urlparse(dsn)
     project = url.path.lstrip('/')
     port = url.port or 7070
     query = dict(parse_qsl(url.query) or {})
-    return KylinCluster(url.hostname, url.username, url.password, port, project, **query)
+    return Kylin(url.hostname, url.username, url.password, port, project, **query)
+
+
+# For compatibility with older versions
+KylinCluster = Kylin
+dsn_proxy = create_kylin
